@@ -31,6 +31,17 @@ class StickMaker(QObject):
         if stdout: sys.stdout.flush()
         return
 
+    def call_cmd(self, cmd):
+        """
+        calls a command, with PATHS set via self.pathSentence,
+        then call self.flush()
+        @param cmd a shell command
+        """
+        call(self.pathSentence+cmd, shell=True)
+        self.flush()
+        return
+        
+
     def log(self, s, timestamp=True):
         """
         print some information for stdout
@@ -59,6 +70,7 @@ class StickMaker(QObject):
 
         parser = argparse.ArgumentParser(description=self.tr('clone a Debian-Live distribution'))
         parser.add_argument('-f','--vfat-size', help=self.tr("size of the VFAT partition, in GB"))
+        parser.add_argument('-i','--iso-filesize', help=self.tr("size of the ISO image, in GB (required only when cloning from a block device)"))
         parser.add_argument('-n','--no-persistence-seed', help=self.tr("do'nt use the file rw.tar.gz to seed the persistence"), action='store_true')
         parser.add_argument('-s','--source', help=self.tr('source of the distribution (required); the keyword OWN means that we are cloning from a Debian-Live disk'), metavar="source", required=True)
         parser.add_argument('device', help=self.tr('the targetted USB stick'))
@@ -73,8 +85,7 @@ class StickMaker(QObject):
         if mounts:
             self.log(self.tr("Unmounting {}").format(', '.join(mounts)))
         for m in mounts:
-            call(self.pathSentence+f"umount {m}", shell=True)
-        self.flush()
+            self.call_cmd(f"umount {m}")
 
         ################### check the sizes #################################
 
@@ -84,7 +95,10 @@ class StickMaker(QObject):
         size = size.decode("utf-8").strip().replace(",",".")
         assert(re.match(r"\d+(\.\d+)?G", size))
         size=float(size.replace("G",""))
-        iso_size = os.stat(args.source).st_size//1024**3
+        try:
+            iso_size = int(float(args.iso_filesize))
+        except:
+            iso_size = os.stat(args.source).st_size//1024**3
         min_persistence = 1 # at least 1 GB for the persistence
 
         if iso_size + min_persistence > size:
@@ -112,17 +126,12 @@ class StickMaker(QObject):
             sectors=int(sectors.decode("utf-8").strip())
             count = 1+sectors//8192 # convert 512 B sectors to 4 MiB blocks
             
-            cmd = f"dd if={sourceDevice} of={args.device} status=progress bs=4M oflag=dsync count={count}"
+            self.call_cmd(f"dd if={sourceDevice} of={args.device} status=progress bs=4M oflag=dsync count={count}")
         else:
             ### Then, the boot sector bears information for two partitions.
-            cmd=f"dd if={args.source} of={args.device} status=progress bs=4M oflag=dsync"
-
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+            self.call_cmd(f"dd if={args.source} of={args.device} status=progress bs=4M oflag=dsync")
         
-        cmd=f"sync; sleep 4; partprobe {args.device}"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"sync; sleep 4; partprobe {args.device}")
 
         inputs="" ### command lines for fdisk
 
@@ -149,7 +158,7 @@ n
 p
 3
 
-+{}G
++{}M
 t
 3
 0b
@@ -160,7 +169,7 @@ p
 
 
 w
-""".format(args.vfat_size)
+""".format(int(float(args.vfat_size)*1024))
         p=Popen(self.pathSentence+f"fdisk {args.device}", shell=True, stdout=PIPE, stderr=PIPE, stdin=PIPE)
         p.stdin.write(inputs.encode("utf-8"))
 
@@ -168,27 +177,19 @@ w
         self.log(message.decode("utf-8"))
         self.log(err.decode("utf-8"))
 
-        cmd=f"sleep 6; partprobe {args.device}"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"sleep 5; partprobe {args.device}; sleep 1")
 
         ################ format VFAT   ####################################
 
-        cmd = f"mkfs.vfat -n DATA {args.device}3"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"mkfs.vfat -n DATA {args.device}3")
 
         ################ format (ext4) ####################################
 
-        cmd = f"mkfs.ext4 -L persistence -F {args.device}4"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"mkfs.ext4 -L persistence -F {args.device}4")
 
         ################## mount the 4th partition ########################
 
-        cmd = f"mkdir -p /tmp/{args.device}4; mount {args.device}4 /tmp/{args.device}4"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"mkdir -p /tmp/{args.device}4; mount {args.device}4 /tmp/{args.device}4")
 
         ################# write the file persistence.conf ################
 
@@ -200,19 +201,13 @@ w
 
         if args.no_persistence_seed==False and os.path.exists("rw.tar.gz"):
             self.log(self.tr("Pre-seed the fourth partition with rw.tar.gz"))
-            cmd = f"zcat rw.tar.gz | (cd /tmp/{args.device}4/; tar xf -)"
-            call(self.pathSentence+cmd, shell=True)
-        self.flush()
+            self.call_cmd(f"zcat rw.tar.gz | (cd /tmp/{args.device}4/; tar xf -)")
 
         #################### little cleanup ###############################
 
-        cmd = f"umount /tmp/{args.device}4; rmdir /tmp/{args.device}4; partprobe {args.device}"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"umount /tmp/{args.device}4; rmdir /tmp/{args.device}4; partprobe {args.device}")
 
-        cmd = f"sfdisk -l {args.device}"
-        call(self.pathSentence+cmd, shell=True)
-        self.flush()
+        self.call_cmd(f"sfdisk -l {args.device}")
 
         self.log(
             "\n=======================================================\n",
