@@ -13,7 +13,7 @@ from monitor import Monitor, CloneMonitor
 
 from subprocess import Popen, PIPE, call
 from datetime import datetime
-import os, re
+import os, re, glob
 
 def createVfatExt4Partitions(device, size="4G"):
     """
@@ -150,7 +150,8 @@ class ToolWizard(QWizard):
             newpackages=new_packages(disk, persistenceNum)
             if not newpackages:
                 packages=self.tr("There are no new packages installed in the persistence partition")
-            packages=self.tr("""\
+            else:
+                packages=self.tr("""\
 ADDITIONAL PACKAGES
 ===================
 """) + "{}\n{}\n".format(disk,len(disk)*"-") + newpackages
@@ -451,21 +452,44 @@ class CloneWizard(QWizard):
         def page2validate(foo=None):
             command="/usr/bin/python3"
             source=page2.field("source")
+            iso_filesize = None
             if source.startswith("AUTOCLONE"):
                 source="own"
+                # now calculate iso_filessize from mountpoint data
+                mountpoint = glob.glob("/usr/lib/live/mount/persistence/sd*1")[0]
+                sourceDevice=mountpoint.replace("/usr/lib/live/mount/persistence","/dev")[:-1]
+                cmd = f"""sudo LANG=C /usr/sbin/sfdisk -l {sourceDevice} | grep '{sourceDevice}1'""".format(sourceDevice=sourceDevice)
+                reply, _ = Popen(cmd, shell=True, stdout=PIPE, stderr=PIPE).communicate()
+                m = re.match(r".* ([.\d]+)G.*", reply.decode())
+                size=float(m.group(1)) # size in GB
+                iso_filesize = size*1024*1024*1024
+
             for device in self.field("selectedDisks").split(","):
                 rindex=mw.rindexFromDev(device)
                 if rindex==None:
                     return True
-                args=[
-                    "{}/makeLiveStick.py".format(mw.wd),
-                    "--vfat-size",
-                    vfatLineEdit.text(),
-                    "--no-persistence-seed",
-                    "--source",
-                    source,
-                    device
-                ]
+                if iso_filesize != None:
+                    args=[
+                        "{}/makeLiveStick.py".format(mw.wd),
+                        "--vfat-size",
+                        vfatLineEdit.text(),
+                        "--no-persistence-seed",
+                        "--iso-filesize",
+                        str(int(iso_filesize/(1024**3))),
+                        "--source",
+                        source,
+                        device
+                    ]
+                else:
+                    args=[
+                        "{}/makeLiveStick.py".format(mw.wd),
+                        "--vfat-size",
+                        vfatLineEdit.text(),
+                        "--no-persistence-seed",
+                        "--source",
+                        source,
+                        device
+                    ]
                 ### add a new tab and a monitor
                 n=mw.ui.tabWidget.count()
                 title=self.tr("Cloning to {}").format(device)
@@ -473,7 +497,7 @@ class CloneWizard(QWizard):
                     QWidget(),
                     self.tr("Cloning to {}").format(device)
                 )
-                m=CloneMonitor(command, args, mw, n, rindex, environ=os.environ)
+                m=CloneMonitor(command, args, mw, n, rindex, iso_filesize = iso_filesize, environ=os.environ)
                 mw.monitors[m]=device
                 m.start()
             return True
@@ -481,6 +505,63 @@ class CloneWizard(QWizard):
         self.addPage(page2)
         return
 
+class DiskinstallWizard(QWizard):
+    """
+    The wizard associated to the "Clone" button of live-clone
+    but only when the --diskinstall option is triggered
+    """
+
+    def __init__(self, mw):
+        """
+        the constructor
+        @param mw a MyMain (<= QMainWindow) instance
+        """
+        QWizard.__init__(self, mw)
+        self.setWindowTitle(self.tr("Clone a Freeduc system to the hard disk"))
+        def page1validate(foo=None):
+            source="own"
+            device="/dev/sda"
+            # now calculate iso_filessize from mountpoint data
+            mountpoints = glob.glob("/usr/lib/live/mount/persistence/sd*1")
+            if not mountpoints:
+                QMessageBox.warning(mw, self.tr("Warning"), self.tr("You are not running this application from a live USB key. Aborting the clone action."))
+                return True
+            mountpoint = mountpoints[0]
+            sourceDevice=mountpoint.replace("/usr/lib/live/mount/persistence","/dev")[:-1]
+            # now sourceDevice is something like /dev/sdb
+            cmd = f"""sudo LANG=C /usr/sbin/sfdisk -l {sourceDevice} | grep '{sourceDevice}1'""".format(sourceDevice=sourceDevice)
+            reply, _ = Popen(cmd, shell=True, stdout=PIPE, stderr=PIPE).communicate()
+            m = re.match(r".* ([.\d]+)G.*", reply.decode())
+            size=float(m.group(1)) # size in GB
+            iso_filesize = size*1024*1024*1024
+            ### add a new tab and a monitor
+            title=self.tr("Cloning to {}").format(device)
+            mw.tabWidget.addTab(
+                QWidget(),
+                self.tr("Cloning to {}").format(device)
+            )
+            command="/bin/sh"
+            args = ["/usr/sbin/cloneToSda"]
+            m=CloneMonitor(command, args, mw, 1, 0, iso_filesize = iso_filesize, environ=os.environ)
+            mw.monitors[m]=device
+            m.start()
+            
+            return True
+        page1=QWizardPage(self)
+        page1.setTitle(self.tr("DANGER ZONE"))
+        page1.setSubTitle(self.tr("Your USB disk is /dev/{usb}, its image would be written on the hard disk /dev/{hard}. Are you really sure that you want to erase and loose any data available on the hard disk /dev/{hard}?").format(usb=mw.owndisk, hard="sda"))
+        layout=QVBoxLayout()
+        cb1 = QCheckBox(self.tr("Yes, I am sure that I want to erase the hard disk."))
+        cb2 = QCheckBox(self.tr("Yes again, I am completely sure!"))
+        page1.registerField("ok1", cb1)
+        page1.registerField("ok2", cb2)
+        layout.addWidget(cb1)
+        layout.addWidget(cb2)
+        page1.setLayout(layout)
+        page1.validatePage=page1validate
+        self.addPage(page1)
+        return
+
 class RunWizard(QWizard):
         """
         wizard for the runButton of live-clone
